@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
 # You may obtain a copy of the License at
@@ -85,8 +84,7 @@ def initConfig(controller):
 
             {"CMD_OPTION": "cinder-backend",
              "PROMPT": "Enter the Cinder backend to be configured",
-             "OPTION_LIST": ["lvm", "gluster", "nfs", "vmdk", "netapp",
-                             "solidfire"],
+             "OPTION_LIST": ["lvm", "nfs", "netapp", "solidfire"],
              "VALIDATORS": [validators.validate_options],
              "DEFAULT_VALUE": "lvm",
              "MASK_INPUT": False,
@@ -140,23 +138,6 @@ def initConfig(controller):
              "CONDITION": False},
         ],
 
-        "CINDERGLUSTERMOUNTS": [
-            {"CMD_OPTION": "cinder-gluster-mounts",
-             "PROMPT": ("Enter a single or comma separated list of gluster "
-                        "volume shares to use with Cinder"),
-             "OPTION_LIST": ["^([\d]{1,3}\.){3}[\d]{1,3}:/.*",
-                             "^[a-zA-Z0-9][\-\.\w]*:/.*"],
-             "VALIDATORS": [validators.validate_multi_regexp],
-             "PROCESSORS": [],
-             "DEFAULT_VALUE": "",
-             "MASK_INPUT": False,
-             "LOOSE_VALIDATION": True,
-             "CONF_NAME": "CONFIG_CINDER_GLUSTER_MOUNTS",
-             "USE_DEFAULT": False,
-             "NEED_CONFIRM": False,
-             "CONDITION": False},
-        ],
-
         "CINDERNFSMOUNTS": [
             {"CMD_OPTION": "cinder-nfs-mounts",
              "PROMPT": ("Enter a single or comma seprated list of NFS exports "
@@ -528,13 +509,6 @@ def initConfig(controller):
          "POST_CONDITION": False,
          "POST_CONDITION_MATCH": True},
 
-        {"GROUP_NAME": "CINDERGLUSTERMOUNTS",
-         "DESCRIPTION": "Cinder gluster Config parameters",
-         "PRE_CONDITION": check_gluster_options,
-         "PRE_CONDITION_MATCH": True,
-         "POST_CONDITION": False,
-         "POST_CONDITION_MATCH": True},
-
         {"GROUP_NAME": "CINDERNFSMOUNTS",
          "DESCRIPTION": "Cinder NFS Config parameters",
          "PRE_CONDITION": check_nfs_options,
@@ -613,7 +587,6 @@ def initSequences(controller):
     )
 
     for key in ('CONFIG_CINDER_NETAPP_VOLUME_LIST',
-                'CONFIG_CINDER_GLUSTER_MOUNTS',
                 'CONFIG_CINDER_NFS_MOUNTS'):
         if key in config:
             config[key] = [i.strip() for i in config[key].split(',') if i]
@@ -644,11 +617,6 @@ def check_lvm_vg_options(config):
             'lvm' in config['CONFIG_CINDER_BACKEND'])
 
 
-def check_gluster_options(config):
-    return (config['CONFIG_CINDER_INSTALL'] == 'y' and
-            'gluster' in config['CONFIG_CINDER_BACKEND'])
-
-
 def check_nfs_options(config):
     return (config['CONFIG_CINDER_INSTALL'] == 'y' and
             'nfs' in config['CONFIG_CINDER_BACKEND'])
@@ -679,15 +647,15 @@ def check_netapp_7modeiscsi_options(config):
 
 def check_netapp_7mode_fc_options(config):
     return (check_netapp_options(config) and
-            config['CONFIG_CINDER_NETAPP_STORAGE_FAMILY'] == "ontap_7mode"
-            and config['CONFIG_CINDER_NETAPP_STORAGE_PROTOCOL'] == "fc")
+            config['CONFIG_CINDER_NETAPP_STORAGE_FAMILY'] == "ontap_7mode" and
+            config['CONFIG_CINDER_NETAPP_STORAGE_PROTOCOL'] == "fc")
 
 
 def check_netapp_vserver_options(config):
-    return (check_netapp_options(config) and
-            config['CONFIG_CINDER_NETAPP_STORAGE_FAMILY'] == "ontap_cluster"
-            and config['CONFIG_CINDER_NETAPP_STORAGE_PROTOCOL'] in
-            ['nfs', 'iscsi'])
+    return (
+        check_netapp_options(config) and
+        config['CONFIG_CINDER_NETAPP_STORAGE_FAMILY'] == "ontap_cluster" and
+        config['CONFIG_CINDER_NETAPP_STORAGE_PROTOCOL'] in ['nfs', 'iscsi'])
 
 
 def check_netapp_eseries_options(config):
@@ -719,7 +687,7 @@ def check_cinder_vg(config, messages):
         if not have_cinders_volume:
             raise exceptions.MissingRequirements("The cinder server should "
                                                  "contain a volume group")
-    match = re.match('^(?P<size>\d+)G$',
+    match = re.match(r'^(?P<size>\d+)G$',
                      config['CONFIG_CINDER_VOLUMES_SIZE'].strip())
     if not match:
         msg = 'Invalid Cinder volumes VG size.'
