@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
 # You may obtain a copy of the License at
@@ -17,7 +16,6 @@ Installs and configures Nova
 """
 
 import os
-import platform
 import socket
 
 from packstack.installer import basedefs
@@ -38,13 +36,6 @@ PLUGIN_NAME_COLORED = utils.color_text(PLUGIN_NAME, 'blue')
 
 
 def initConfig(controller):
-    if platform.linux_distribution()[0] == "Fedora":
-        primary_netif = "em1"
-        secondary_netif = "em2"
-    else:
-        primary_netif = "eth0"
-        secondary_netif = "eth1"
-
     nova_params = {
         "NOVA": [
             {"CMD_OPTION": 'nova-db-purge-enable',
@@ -176,7 +167,7 @@ def initConfig(controller):
                         "'name':'default'}, {...}] "),
              "OPTION_LIST": [],
              "VALIDATORS": [],
-             "DEFAULT_VALUE": "",
+             "DEFAULT_VALUE": "[]",
              "MASK_INPUT": False,
              "LOOSE_VALIDATION": True,
              "CONF_NAME": "CONFIG_NOVA_PCI_ALIAS",
@@ -191,7 +182,7 @@ def initConfig(controller):
                         "'name':'default'}, {...}]"),
              "OPTION_LIST": [],
              "VALIDATORS": [],
-             "DEFAULT_VALUE": "",
+             "DEFAULT_VALUE": "[]",
              "MASK_INPUT": False,
              "LOOSE_VALIDATION": True,
              "CONF_NAME": "CONFIG_NOVA_PCI_PASSTHROUGH_WHITELIST",
@@ -232,11 +223,6 @@ def initSequences(controller):
     if controller.CONF['CONFIG_NOVA_INSTALL'] != 'y':
         return
 
-    if controller.CONF['CONFIG_NEUTRON_INSTALL'] == 'y':
-        network_title = ('Preparing OpenStack Network-related '
-                         'Nova entries')
-        network_function = create_neutron_manifest
-
     novaapisteps = [
         {'title': 'Preparing Nova API entries',
          'functions': [create_api_manifest]},
@@ -250,8 +236,8 @@ def initSequences(controller):
          'functions': [create_sched_manifest]},
         {'title': 'Preparing Nova VNC Proxy entries',
          'functions': [create_vncproxy_manifest]},
-        {'title': network_title,
-         'functions': [network_function]},
+        {'title': 'Preparing OpenStack Network-related Nova entries',
+         'functions': [create_neutron_manifest]},
         {'title': 'Preparing Nova Common entries',
          'functions': [create_common_manifest]},
     ]
@@ -397,7 +383,7 @@ def create_compute_manifest(config, messages):
                 )
                 ssl_host = config['CONFIG_CONTROLLER_HOST']
                 service = 'ceilometer'
-                generate_ssl_cert(config, host, service, ssl_key_file,
+                generate_ssl_cert(config, ssl_host, service, ssl_key_file,
                                   ssl_cert_file)
 
         fw_details = dict()
@@ -449,9 +435,6 @@ def create_vncproxy_manifest(config, messages):
 def create_common_manifest(config, messages):
     global compute_hosts, network_hosts
 
-    network_type = (config['CONFIG_NEUTRON_INSTALL'] == "y" and
-                    'neutron' or 'nova')
-    network_multi = len(network_hosts) > 1
     dbacces_hosts = set([config.get('CONFIG_CONTROLLER_HOST')])
     dbacces_hosts |= network_hosts
 
@@ -475,14 +458,7 @@ def create_common_manifest(config, messages):
         else:
             config['CONFIG_NOVA_SQL_CONN_NOPW'] = sqlconn
 
-        # for nova-network in multihost mode each compute host is metadata
-        # host otherwise we use api host
-        if (network_type == 'nova' and network_multi and
-                host in compute_hosts):
-            metadata = host
-        else:
-            metadata = config['CONFIG_CONTROLLER_HOST']
-        config['CONFIG_NOVA_METADATA_HOST'] = metadata
+        config['CONFIG_NOVA_METADATA_HOST'] = config['CONFIG_CONTROLLER_HOST']
 
     if config['CONFIG_AMQP_ENABLE_SSL'] == 'y':
         nova_hosts = compute_hosts
